# Supported Models

| Model | Supported | Note |
|---------|-----------|------|
| DeepSeek v3 | ✅|||
| DeepSeek R1 | ✅|||
| DeepSeek Distill (Qwen/LLama) |✅||
| Qwen2-VL | ✅ ||
| Qwen2-Audio | ✅ ||
| Qwen2.5 | ✅ ||
| Qwen2.5-VL | ✅ ||
| QwQ-32B | ✅ ||
| MiniCPM |✅| |
| LLama3.1/3.2 | ✅ ||
| Mistral |  | Need test |
| DeepSeek v2.5 | |Need test |
| Gemma-2 |  |Need test|
| Baichuan |  |Need test|
| Internlm | ✅ ||
| ChatGLM | ❌ | Plan in Q2|
| InternVL2.5 | ✅ ||
| GLM-4v |  |Need test|
| Molomo | ✅ ||
| LLaVA1.5 | | Need test|
| Mllama |  |Need test|
| LLaVA-Next |  |Need test|
| LLaVA-Next-Video |  |Need test|
| Phi-3-Vison/Phi-3.5-Vison |  |Need test|
| Ultravox |  |Need test|
